#
# spec file for package metamath
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2022 Aaron Puchert
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Do not build LaTeX docs on SLES.
# Also don't build on Tumbleweed. Seems that tabu broke with TeXlive 2022.
# https://github.com/metamath/metamath-book/issues/235.
%if 0%{?is_opensuse} && 0%{?suse_version} <= 1500
%bcond_without  latex_doc
%else
%bcond_with     latex_doc
%endif

%define book_version 20190602
%define book_tag second_edition

# Global definitions
Name:           metamath
Version:        0.198
Release:        7.9
Summary:        Formal proof verifier and proof assistant
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Math
URL:            http://us.metamath.org/
Source0:        https://github.com/metamath/metamath-exe/archive/refs/tags/v%{version}.tar.gz#/metamath-%{version}.tar.gz
Source1:        https://github.com/metamath/metamath-book/archive/refs/tags/%{book_tag}.tar.gz#/metamath-book-%{book_version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc
%if %{with latex_doc}
BuildRequires:  texlive-bibtex-bin
BuildRequires:  texlive-latex-bin
BuildRequires:  texlive-makeindex-bin
BuildRequires:  tex(amssymb.sty)
BuildRequires:  tex(anysize.sty)
BuildRequires:  tex(breqn.sty)
BuildRequires:  tex(hyperref.sty)
BuildRequires:  tex(longtable.sty)
BuildRequires:  tex(makecell.sty)
BuildRequires:  tex(microtype.sty)
BuildRequires:  tex(needspace.sty)
BuildRequires:  tex(tabu.sty)
Suggests:       %{name}-book = %{book_version}
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The Metamath language is a language to write theorems and formal proofs for
them. The Metamath program can parse files in the Metamath language and verify
the proofs. You can find examples of theories developed in Metamath on the
website.

%package book
Summary:        The Metamath book
License:        CC0-1.0
Group:          Documentation/Other
Version:        %{book_version}
Release:        7.9
Recommends:     %{name} = %{VERSION}
BuildArch:      noarch

%description book
The Metamath book, written by Norman Megill with extensive revisions by
David A. Wheeler, provides an in-depth understanding of the Metamath language
and program. The first part of the book also includes an easy-to-read informal
discussion of abstract mathematics and computers, with references to other
proof verifiers and automated theorem provers.

%prep
%setup -q -a 1 -n metamath-exe-%{VERSION}/

%build
autoreconf -fi
%configure
make %{?_smp_mflags}

# Build documentation as outlined in the LaTeX file.
%if %{with latex_doc}
pushd metamath-book-%{book_tag}
echo "Package amsmath Warning: Foreign command \\atop;
LaTeX Font Warning: Font shape \`TS1/cmtt/bx/n' undefined" >>allowed-errors
./generate-pdf
popd
%endif

%install
%make_install
%if %{with latex_doc}
install -Dm0644 metamath-book-%{book_tag}/metamath.pdf \
    %{buildroot}%{_datadir}/%{name}/%{name}.pdf
%endif

%files
%license LICENSE.TXT
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{ext_man}

%if %{with latex_doc}
%files book
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/%{name}.pdf
%endif

%changelog
* Sat Apr 30 2022 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Disable build of metamath-book on Tumbleweed: it doesn't build
  with TeXlive 2022 because of what seems to be a bug in
  texlive-tabu. (gh#metamath/metamath-book#235)
- Use symbolic dependencies for required TeX packages.
* Sat Jan 15 2022 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Update to version 0.198.
  * Put two spaces between $c,v on same line in /rewrap.
  * Fix cosmetic bug in WRITE SOURCE ... /REWRAP that prevented end
    of sentence (e.g. period) from appearing in column 79, thus
    causing some lines to be shorter than necessary.
- Use tarballs from GitHub because they have versioned URLs.
- Drop data package. There are no (recent) releases and the files
  are just taken verbatim from https://github.com/metamath/set.mm
  anyway. Users will likely want to work on these in their home
  directory anyway, since they're not libraries.
- Only suggest the book to install.
* Wed Mar  3 2021 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Update to version 0.196.
  * Fix bug causing new axioms to be used by MINIMIZE_WITH.
  * Add "Claim" to bib ref types.
  * Remove error check for $e <- $f assignments.
  * Check for discouragement tags in *ALT, *OLD labels in
    VERIFY MARKUP.
  * Add underscore checking in VERIFY MARKUP and add /UNDERSCORE-
    _SKIP qualifier; also check for trailing space on lines.
  * Refine prevention of WRITE SOURCE.../REWRAP from modifying
    comments containing "<HTML>".
  * Allow space in TOOLS> BREAK.
  * Add checking for mathbox independence to VERIFY MARKUP;
    add /MATHBOX_SKIP.
  * "PROVE =" will now resume the previous MM-PA session if there
    was one; allow "~" to start/end with blank (meaning first/last
    statement); add "@1234".
  * Add /INCLUDE_MATHBOXES to to IMPROVE; notify user upon ASSIGN
    from another mathbox.
  * Print message when IMPROVE or MINIMIZE_WITH uses another mathbox.
  * Add CONJECTURE, RESULT to [bib] keywords.
  * Add HELP BIBLIOGRAPHY.
  * Added CONCLUSION FACT INTRODUCTION PARAGRAPH SCOLIA SCOLION
    SUBSECTION TABLE to [bib] keywords.
  * Added WRITE SOURCE ... /EXTRACT ....
  * Make the output of /EXTRACT stable in the sense that, with the
    same <label-list> parameter, extract(extract(file)) =
    extract(file) except that the date stamp at the top will be
    updated. (The first extraction even if "*" will usually be
    different because it discards non-relevant content. Note that
    the include file directives "$( $[ Begin..." etc. and comments
    with "$j" are currently discarded.)
  * Add keyword "htmlexturl" to $t statement in .mm file.
  * Prevent "htmlexturl" links from wrapping.
  * Temporarily disable /REWRAP until bug fixed.
  * Fix bug that deleted comments that were followed by ${, $}, $c,
    $v, $d on the same line.
- Relax dependencies.
* Fri Dec 20 2019 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Update to version 0.180.
  * MINIMIZE_WITH axiom trace now starts from current NEW_PROOF
    instead of SAVEd proof.
  * Make sure traceback flags are cleared after MINIMIZE_WITH.
  * Add url pointer to HELP WRITE SOURCE /SPLIT.
  * Clarify HELP WRITE SOURCE /REWRAP.
  * Add bug check info for user.
  * Use '|->' (not 'e.') as syntax hint for maps-to.
  * Remove extraneous </TD>.
  * Fix "line 0" in error msg when label clashes with math symbol.
  * Improve TOOLS> HELP INSERT, DELETE.
  * Change bug 1511 to error message.
  * Trigger Most Recent link on mmtheorems.html when there is a
    mathbox statement (currently set.mm and iset.mm).
  * Improve help for TOOLS> DELETE and SUBSTITUTE.
  * Change "htmlHome" in warnings to "htmlhome".
* Wed Sep 25 2019 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Update to version 0.178.
- Update book to version 20190602.
- Remove Windows executable from sources before building.
* Wed May  1 2019 aaronpuchert@alice-dsl.net
- Update to version 0.177.
- Update book to version 20190407.
- Use man page from upstream now.
* Thu Apr  4 2019 aaronpuchert@alice-dsl.net
- Change SPDX identifier to GPL-2.0-or-later, as README.TXT states.
* Tue Mar 19 2019 aaronpuchert@alice-dsl.net
- Fix dependency versions - since the book has a different version,
  we need to be careful which version we refer to.
* Sat Mar 16 2019 aaronpuchert@alice-dsl.net
- Fix version number.
* Sat Mar 16 2019 Jan Engelhardt <jengelh@inai.de>
- Remove %%if..%%endif guards that do not change the build result.
- Itemize the list in the description.
* Sat Mar 16 2019 aaronpuchert@alice-dsl.net
- Update to version 0.175.
- Update Metamath book to version 20190307.
- Use date as version number for Metamath book, because it isn't
  versioned alongside the program.
- Move source links into comments, as they aren't stable. They
  always point to the latest version, which isn't compatible with
  download_files service runs.
* Thu Mar  7 2019 aaronpuchert@alice-dsl.net
- Update to version 0.174.
- Package Metamath book separately.
* Tue Jan  8 2019 aaronpuchert@alice-dsl.net
- Update to version 0.171.
* Mon Aug  6 2018 aaronpuchert@alice-dsl.net
- Update to version 0.163.
- Recommend data package, make it noarch.
* Sun Feb  4 2018 aaronpuchert@alice-dsl.net
- Add a brief manual page.
- Do not build LaTeX docs on SLES, because TeXlive doesn't seem up
  to the task there.
* Sun Feb  4 2018 aaronpuchert@alice-dsl.net
- Update to version 0.161.
- Also build documentation.
- Package data base files separately.
* Tue Oct 24 2017 aaronpuchert@alice-dsl.net
- Update version to 0.155.
* Wed Jul 19 2017 aaronpuchert@alice-dsl.net
- Really update version to 0.146.
* Wed Jul 19 2017 aaronpuchert@alice-dsl.net
- Update version to 0.146.
* Sat Apr 15 2017 aaronpuchert@alice-dsl.net
- Update version to 0.139.
* Mon Oct 31 2016 aaronpuchert@alice-dsl.net
- Initial release of the package base on version 0.130.
